fedex.services.address_validation_service

Package fedex :: Package services :: Module address_validation_service |
[hide private]
[frames] | no frames]

# Module address_validation_service

source code

# Address Validation Service Module

This package contains the shipping methods defined by Fedex's AddressValidationService WSDL file. Each is encapsulated in a class for easy access. For more details on each, refer to the respective class's documentation.

Classes | [hide private]
| FedexAddressValidationRequest This class allows you validate anywhere from one to a hundred addresses in one go.

Variables | [hide private]
| __package__ = ``'``fedex.services``'``